package com.goldenwater.slaj.eme.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eme.mapper.BusiTeamInfoMapper;
import com.goldenwater.slaj.eme.domain.BusiTeamInfo;
import com.goldenwater.slaj.eme.service.IBusiTeamInfoService;

/**
 * 应急救援队伍 服务层实现
 */
@Service
public class BusiTeamInfoServiceImpl implements IBusiTeamInfoService {

    @Autowired
    private BusiTeamInfoMapper busiTeamInfoMapper;

    @Override
    public BusiTeamInfo selectBusiTeamInfoByGuid(String guid) {
        return busiTeamInfoMapper.selectBusiTeamInfoByGuid(guid);
    }

    @Override
    public List<BusiTeamInfo> selectBusiTeamInfoList(BusiTeamInfo busiTeamInfo) {
        return busiTeamInfoMapper.selectBusiTeamInfoList(busiTeamInfo);
    }

    @Override
    public int insertBusiTeamInfo(BusiTeamInfo busiTeamInfo) {
        return busiTeamInfoMapper.insertBusiTeamInfo(busiTeamInfo);
    }

    @Override
    public int updateBusiTeamInfo(BusiTeamInfo busiTeamInfo) {
        return busiTeamInfoMapper.updateBusiTeamInfo(busiTeamInfo);
    }

    @Override
    public int deleteBusiTeamInfoByGuid(String guid) {
        return busiTeamInfoMapper.deleteBusiTeamInfoByGuid(guid);
    }

    @Override
    public int deleteBusiTeamInfoByGuids(String[] guids) {
        return busiTeamInfoMapper.deleteBusiTeamInfoByGuids(guids);
    }
}
